@@ -6,6 +6,7 @@ OP_GTE = "gte"
 OP_ILIKE = "ilike"
 OP_IN = "in"
 OP_EMPTY = "empty"
+OP_NOT_EMPTY = "not_empty"
 OP_CONTAINS = "contains"
 OP_LT = "lt"
 OP_GT = "gt"
@@ -17,6 +18,7 @@ OPERATORS_MAPPING: Dict[str, Tuple[str, Callable]] = {
     OP_ILIKE: ("ilike", lambda v: f"%{v}%"),
     OP_IN: ("in_", lambda v: v),
     OP_EMPTY: ("is_", lambda v: None),
+    OP_NOT_EMPTY: ("isnot", lambda v: None),
     OP_CONTAINS: ("contains", lambda v: v),
     OP_LT: ("__lt__", lambda v: v),
     OP_GT: ("__gt__", lambda v: v),
